<?php

namespace SlotDb\Cli\Command;

use SlotDb\Client\SlotDbClient;
use Symfony\Component\Console\Attribute\AsCommand;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Output\OutputInterface;

#[AsCommand(name:"export", description:"Export the database to a file")]
class ExportCommand extends BaseCommand
{
    public function __construct(
        private readonly SlotDbClient $client
    )
    {
        parent::__construct();
    }

    protected function configure()
    {
        $this->addOption("all-props", "A", InputOption::VALUE_NONE, "Include all slot properties. If not specified, properties that match the group property will be stripped.");
        $this->addOption("output", "o", InputOption::VALUE_REQUIRED, "Write to file instead of standard output");
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        // TODO implement paging
        
        $groups = $this->client->findGroups();
        $indexedGroups = array_combine(
            array_map(fn($group) => $group['_group'], $groups),
            array_values($groups)
        );

        $slots = $this->client->findSlots();
        if (!$input->getOption("all-props")) {
            foreach ($slots as &$slot) {
                if ($slot['_group'] && isset($indexedGroups[$slot['_group']])) {
                    $group = $indexedGroups[$slot['_group']];
                    foreach ($slot as $k=>$v) {
                        if (str_starts_with($k,"_")) continue;
                        if (isset($group[$k]) && $group[$k] == $v) {
                            unset($slot[$k]);
                        }
                    }
                }
            }
        }

        $export = json_encode([
            'comment' => "This is an exported SlotDB database.",
            'timestamp' => date('Y-m-d H:i:s P'),
            'generator' => "SlotCLI v".APP_VERSION." (".APP_BUILT.")",
            'export' => [
                'schemas' => [],
                'hooks' => [],
                'groups' => $groups,
                'slots' => $slots,
            ],
        ], JSON_PRETTY_PRINT|JSON_UNESCAPED_SLASHES);

        if ($input->getOption("output")) {
            $file = $input->getOption("output");
            file_put_contents($file, $export."\n");
        } else {
            $output->writeln($export);
        }

        return self::SUCCESS;
    }

}
