<?php

namespace SlotDb\Cli\Command;

use SlotDb\Client\SlotDbClient;
use Symfony\Component\Console\Attribute\AsCommand;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Style\SymfonyStyle;

#[AsCommand(name:"import", description:"Import database from file")]
class ImportCommand extends BaseCommand
{
    public function __construct(
        private readonly SlotDbClient $client
    )
    {
        parent::__construct();
    }

    protected function configure()
    {
        $this->addOption("hard-reset", "R", InputOption::VALUE_NONE, "Completely wipe the database before importing the new data.");
        $this->addArgument("filename", InputArgument::OPTIONAL, "Filename to read from, if omitted read standard input.");
        $this->addOption("assume-yes", "y", InputOption::VALUE_NONE, "Assume yes on all questions.");
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        if ($input->getArgument("filename")) {
            $file = $input->getArgument("filename");
            $json = file_get_contents($file);
        } else {
            $json = stream_get_contents(STDIN);
        }

        $export = json_decode($json);

        $output->writeln("File was generated <fg=yellow>{$export->timestamp}</>");
        $output->writeln("Generated using <fg=yellow>{$export->generator}</>");
        $output->writeln("");
        if (!$input->getOption("assume-yes")) {
            $confirm = (new SymfonyStyle($input, $output))->confirm("Do you want to continue", false);
            if (!$confirm) {
                return self::FAILURE;
            }
            $output->writeln("");
        }

        $output->writeln("+ <options=bold>Importing schemas...</>");

        $output->writeln("+ <options=bold>Importing hooks...</>");

        $output->writeln("+ <options=bold>Importing groups...</>");
        foreach ($export->export->groups as $group) {
            $output->writeln("  - <fg=green>".$group->_group."</>");
        }

        $output->writeln("+ <options=bold>Importing slots...</>");
        foreach ($export->export->slots as $slot) {
            $output->writeln("  - <fg=green>".$slot->_slot."</>");
        }

        return self::SUCCESS;
    }

}
